From c5e58c85e743c3c7b133234588e2010612166f8f Mon Sep 17 00:00:00 2001
From: Michael Paquier <michael@otacoo.com>
Date: Mon, 23 Feb 2015 15:23:44 +0900
Subject: [PATCH 2/2] Add regress_dynamic as a test module

This simple extension has the characteristic to only contain non-static
regression test content, and is aimed to test if pg_regress is able to
generate appropriately input and output directories when they do not
exist.
---
 src/test/modules/regress_dynamic/.gitignore              |  8 ++++++++
 src/test/modules/regress_dynamic/Makefile                | 16 ++++++++++++++++
 src/test/modules/regress_dynamic/README                  |  6 ++++++
 src/test/modules/regress_dynamic/input/basic.source      |  9 +++++++++
 src/test/modules/regress_dynamic/output/basic.source     | 11 +++++++++++
 .../modules/regress_dynamic/regress_dynamic--1.0.sql     |  8 ++++++++
 src/test/modules/regress_dynamic/regress_dynamic.control |  5 +++++
 7 files changed, 63 insertions(+)
 create mode 100644 src/test/modules/regress_dynamic/.gitignore
 create mode 100644 src/test/modules/regress_dynamic/Makefile
 create mode 100644 src/test/modules/regress_dynamic/README
 create mode 100644 src/test/modules/regress_dynamic/input/basic.source
 create mode 100644 src/test/modules/regress_dynamic/output/basic.source
 create mode 100644 src/test/modules/regress_dynamic/regress_dynamic--1.0.sql
 create mode 100644 src/test/modules/regress_dynamic/regress_dynamic.control

diff --git a/src/test/modules/regress_dynamic/.gitignore b/src/test/modules/regress_dynamic/.gitignore
new file mode 100644
index 0000000..122ede3
--- /dev/null
+++ b/src/test/modules/regress_dynamic/.gitignore
@@ -0,0 +1,8 @@
+# Generated sub-directories
+/log/
+/results/
+/tmp_check/
+
+# Input and output directories of regression tests
+/expected/
+/sql/
diff --git a/src/test/modules/regress_dynamic/Makefile b/src/test/modules/regress_dynamic/Makefile
new file mode 100644
index 0000000..2cab345
--- /dev/null
+++ b/src/test/modules/regress_dynamic/Makefile
@@ -0,0 +1,16 @@
+EXTENSION = regress_dynamic
+DATA = regress_dynamic--1.0.sql
+PGFILEDESC = "regress_dynamic - extension with only non-static regression tests"
+
+REGRESS = basic
+
+ifdef USE_PGXS
+PG_CONFIG = pg_config
+PGXS := $(shell $(PG_CONFIG) --pgxs)
+include $(PGXS)
+else
+subdir = src/test/modules/regress_dynamic
+top_builddir = ../../../..
+include $(top_builddir)/src/Makefile.global
+include $(top_srcdir)/contrib/contrib-global.mk
+endif
diff --git a/src/test/modules/regress_dynamic/README b/src/test/modules/regress_dynamic/README
new file mode 100644
index 0000000..b039e5e
--- /dev/null
+++ b/src/test/modules/regress_dynamic/README
@@ -0,0 +1,6 @@
+regress_dynamic
+===============
+
+regress_dynamic is an extension used to test that pg_regress correctly
+creates input and output paths when regression test suite of an extension
+only contain non-static content with empty sql/ and expected/ folders.
diff --git a/src/test/modules/regress_dynamic/input/basic.source b/src/test/modules/regress_dynamic/input/basic.source
new file mode 100644
index 0000000..1d7031d
--- /dev/null
+++ b/src/test/modules/regress_dynamic/input/basic.source
@@ -0,0 +1,9 @@
+--
+-- regress_dynamic
+--
+
+-- Initialization
+CREATE EXTENSION regress_dynamic;
+
+-- Simple test
+SELECT * FROM dummy_tab;
diff --git a/src/test/modules/regress_dynamic/output/basic.source b/src/test/modules/regress_dynamic/output/basic.source
new file mode 100644
index 0000000..f666627
--- /dev/null
+++ b/src/test/modules/regress_dynamic/output/basic.source
@@ -0,0 +1,11 @@
+--
+-- regress_dynamic
+--
+-- Initialization
+CREATE EXTENSION regress_dynamic;
+-- Simple test
+SELECT * FROM dummy_tab;
+ id 
+----
+(0 rows)
+
diff --git a/src/test/modules/regress_dynamic/regress_dynamic--1.0.sql b/src/test/modules/regress_dynamic/regress_dynamic--1.0.sql
new file mode 100644
index 0000000..c7a19c9
--- /dev/null
+++ b/src/test/modules/regress_dynamic/regress_dynamic--1.0.sql
@@ -0,0 +1,8 @@
+/* regress_dynamic/regress_dynamic--1.0.sql */
+
+-- complain if script is sourced in psql, rather than via CREATE EXTENSION
+\echo Use "CREATE EXTENSION regress_dynamic" to load this file. \quit
+
+CREATE TABLE dummy_tab (
+	id int
+);
diff --git a/src/test/modules/regress_dynamic/regress_dynamic.control b/src/test/modules/regress_dynamic/regress_dynamic.control
new file mode 100644
index 0000000..643b946
--- /dev/null
+++ b/src/test/modules/regress_dynamic/regress_dynamic.control
@@ -0,0 +1,5 @@
+# regress_dynamic extension
+comment = 'regress_dynamic - extension with only non-static regression tests'
+default_version = '1.0'
+module_pathname = '$libdir/regress_dynamic'
+relocatable = true
-- 
2.3.0

